==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/recent_me_url.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

RecentMeUrl = Union[raw.types.RecentMeUrlChat, raw.types.RecentMeUrlChatInvite, raw.types.RecentMeUrlStickerSet, raw.types.RecentMeUrlUnknown, raw.types.RecentMeUrlUser]


# noinspection PyRedeclaration
class RecentMeUrl(TLObject):  # type: ignore
    """This base type has 5 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`RecentMeUrlChat <pyrogram.raw.types.RecentMeUrlChat>`
            - :obj:`RecentMeUrlChatInvite <pyrogram.raw.types.RecentMeUrlChatInvite>`
            - :obj:`RecentMeUrlStickerSet <pyrogram.raw.types.RecentMeUrlStickerSet>`
            - :obj:`RecentMeUrlUnknown <pyrogram.raw.types.RecentMeUrlUnknown>`
            - :obj:`RecentMeUrlUser <pyrogram.raw.types.RecentMeUrlUser>`
    """

    QUALNAME = "pyrogram.raw.base.RecentMeUrl"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/recent_me_url.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

RecentMeUrl = Union[raw.types.RecentMeUrlChat, raw.types.RecentMeUrlChatInvite, raw.types.RecentMeUrlStickerSet, raw.types.RecentMeUrlUnknown, raw.types.RecentMeUrlUser]


# noinspection PyRedeclaration
class RecentMeUrl:  # type: ignore
    """This base type has 5 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`RecentMeUrlChat <pyrogram.raw.types.RecentMeUrlChat>`
            - :obj:`RecentMeUrlChatInvite <pyrogram.raw.types.RecentMeUrlChatInvite>`
            - :obj:`RecentMeUrlStickerSet <pyrogram.raw.types.RecentMeUrlStickerSet>`
            - :obj:`RecentMeUrlUnknown <pyrogram.raw.types.RecentMeUrlUnknown>`
            - :obj:`RecentMeUrlUser <pyrogram.raw.types.RecentMeUrlUser>`
    """

    QUALNAME = "pyrogram.raw.base.RecentMeUrl"
